pm4py.objects.random\_variables.gamma package
=============================================

Submodules
----------

pm4py.objects.random\_variables.gamma.random\_variable module
-------------------------------------------------------------

.. automodule:: pm4py.objects.random_variables.gamma.random_variable
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pm4py.objects.random_variables.gamma
   :members:
   :undoc-members:
   :show-inheritance:
